@@ -865,6 +865,8 @@ sub _getRealIndex($$) {
 }
 
 #------------------------------------------------------------------------------
+# Concatenate several header/footer options into header/footer strings.
+# Return original options array-ref and header/footer strings.
 #------------------------------------------------------------------------------
 sub _normMenueOpts($){
     my ($opts) = @_;
@@ -1097,10 +1099,9 @@ sub _jump($$)
     my $call = $menue->[$o]->{'jump'};
     my $args = defined $menue->[$o]->{'argv'} ? $menue->[$o]->{'argv'} : undef;
 
-    #FIXME: deprecated, callback should handle data struct by its own 
-    #FIXME: $call->(@{$args});
-    $call->($args);
-    return;
+    if( ref $call eq 'CODE' ) { $call->($args); return; }
+    Log("\nERROR: Can't call function $call(). It's not a code reference.");
+    sleep 5;
 }
 
 #------------------------------------------------------------------------------
@@ -1158,10 +1159,7 @@ sub _flushChar($){
 #------------------------------------------------------------------------------
 sub _unique($$){
     my ($o,$maxNum) = @_;
-    if( $$o =~ /^\n$/ ){ # default 0 if got ENTER
-        $$o = 0;
-        return 1;
-    }
+    return 1    if( $$o =~ s/^\n$/0/ ); # set default option 0 if we got ENTER
     return 1    if( $$o*10 > $maxNum);
 }
 
@@ -1192,6 +1190,7 @@ sub _getNumber($) {
         if( $maxNum > 9 ) {
             _flushChar($o);
             my $oo=_getChar('^\d+$');
+            last    if( $oo eq "\n" );
             $o=10*$o+$oo;
         }
         last   if( $o <= $maxNum && $o > -1 );
