@@ -38,13 +38,25 @@ sub main
 	my ($self) = @_;
     my $o = Script::Toolbox->new( $O );
 
-    my $m = Script::Toolbox::Util::Menues->new({'SubMenue1'=>[{'label'=>'test','value'=>10}]});
-       $m->addMenue({'MainMenue'=>[{'label'=>'test1', 'value'=>1 ,'readOnly'=>1},
-                                   {'label'=>'test2', 'value'=>20,},
+    my $m = Script::Toolbox::Util::Menues->new({'SubMenue2'=>[{'label'=>'test','value'=>10}]});
+       $m->addMenue({'MainMenue'=>[{'label'=>'test1', 'value'=>1 },
+                                   {'label'=>'test2', 'value'=>'readOnly','readOnly'=>1},
                                    {'label'=>'test3', 'value'=>30,},
-                                   {'label'=>'Untermenue 1','jump'=>'SubMenue1'}
+                                   {'label'=>'test4',},
+                                   {'label'=>'test5',},
+                                   {'label'=>'test6',},
+                                   {'label'=>'test7',},
+                                   {'label'=>'test8',},
+                                   {'label'=>'test9',},
+                                   {'label'=>'test10',          'value'=>30,},
+                                   {'label'=>'Untermenue 1',    'jump'=>'SubMenue1'},
+                                   {'label'=>'Untermenue 2',    'jump'=>'SubMenue2'},
+                                   {'label'=>'InvalidSubMenue', 'jump'=>'SubMenueX'}
                                   ]});
+       $m->addMenue({'SubMenue1'=>[{'label'=>'SubMenue1 Test','value'=>40}]});
+
        $m->setAutoHeader();
+       $m->setFooter('MainMenue', 'Test:Autoheader, ininite run');
     my $r = $m->run('MainMenue',-1);
 
     printf "\n%s\n", '-' x 20;
@@ -53,11 +65,12 @@ sub main
        $v = $m->getMatching('MainMenue','(1|3)','number','value');
     printf "Values of Numbers /(1|3)/: %s\n", join ' ', @{$v};
        $v = $m->getMatching('MainMenue','\d+','value','label');
-    printf "Labels of Values /\d+/   : %s\n", join ' ', @{$v};
+    printf "Labels of Values /%s/   : %s\n", '\d+', join ' ',  @{$v};
     printf "\n%s\n", '-' x 20;
 
+    $m->setFooter('MainMenue', 'Test:Autoheader, single run with reaction code');
     while( $m->run('MainMenue')) {
-            if( $m->currNumber('MainMenue') == 1 ) {
+            if( $m->currNumber('MainMenue') == 2 ) {
                 my $v = $m->currValue('MainMenue');
                 my $nv= $v == 0 ? 1 : 0;
                 my $lb= $nv == 0 ? 'test1-off' : 'test1-on';
